@@ -63,6 +63,7 @@ def setup(**settings_patches):
                 if has_uwsgi:
                     new_version = tuple(map(lambda x: int(x), uwsgi_src_folder.split('-')[-1].split('.')))
                     current_version = tuple(map(lambda x: int(x), local('uwsgi --version', capture=True).split('.')))
+                    print new_version, current_version
                     if new_version == current_version:
                         install_uwsgi = confirm('Re-install Uwsgi?', default=False)
 
@@ -153,7 +154,7 @@ def setup(**settings_patches):
         'Match Group beanstalk',
         '       ForceCommand /usr/bin/bs_ssh_entry',
     ]
-    local(sed('$a\\\n{command}'.format(command='\n'.join(new_lines)), sshd_config))
+    local(sed('$a\\\n{command}'.format(command='\\\n'.join(new_lines)), sshd_config))
     local(sed('s/^AllowGroups (.*)$/AllowGroups \\1 beanstalk/g', sshd_config, '-E'))
 
     # Apache conf
